<?php

namespace Drupal\customers_canvas_commerce\Controller;

use Drupal\commerce_order\Entity\OrderItem;
use Drupal\Component\Serialization\Json;
use Drupal\Component\Utility\Html;
use Drupal\Core\Controller\ControllerBase;

/**
 * Controller for Commerce-based builder.
 *
 * @package Drupal\customers_canvas_commerce\Controller
 */
class Builder extends ControllerBase {

  /**
   * Display the builder for a particular user and entity.
   *
   * @param \Drupal\commerce_order\Entity\OrderItem $commerce_order_item
   *   The order item used to track this product.
   *
   * @return array
   *   Return markup render array.
   */
  public function content(OrderItem $commerce_order_item) {
    /** @var \Drupal\commerce_product\Entity\ProductVariation $cc_entity */
    /** @var \Drupal\commerce_order\Entity\Order $order */
    $cc_entity = $commerce_order_item->getPurchasedEntity();
    $order = $commerce_order_item->getOrder();
    $user = $order->getCustomer();
    $state_id = $commerce_order_item->get('cc_state_id')->getString();

    $product_json = $cc_entity->get('cc_product_json');
    if ($product_json) {
      $product_json = $product_json->getValue()[0]['value'];
      if ($state_id !== '') {
        $product_json = HTML::escape($state_id);
      }
      $builder_json = $this->config('customers_canvas.settings')->get('builder_json');

      // Inject settings for user id.
      // See https://customerscanvas.com/docs/cc/customerscanvas.iframeapi.configuration.iconfiguration.htm
      $builder_json = JSON::decode($builder_json);
      $builder_json['userId'] = $user->id();
      $builder_json = JSON::encode($builder_json);

      return [
        '#theme' => 'customers_canvas_builder',
        '#owner' => $user,
        '#entity' => $cc_entity,
        '#finish_form' => $this->formBuilder()->getForm('Drupal\customers_canvas\Form\Builder', [
          'cc_entity' => $cc_entity,
          'owner' => $user,
          'state_id' => $state_id,
          'order_item_id' => $commerce_order_item->id(),
        ]),
        '#attached' => [
          'library' => ['customers_canvas/builder'],
          'drupalSettings' => [
            'customersCanvas' => [
              'productJson' => $product_json,
              'builderJson' => $builder_json,
            ],
          ],
        ],
      ];
    }
  }

}
